package com.fizz.business.service;

import java.util.List;
import com.fizz.business.domain.SetupTmMesh;

/**
 * 光整机插入量Service接口
 * 
 * @author Joshi
 * @date 2025-09-26
 */
public interface ISetupTmMeshService 
{
    /**
     * 查询光整机插入量
     * 
     * @param steelGrade 光整机插入量主键
     * @return 光整机插入量
     */
    public SetupTmMesh selectSetupTmMeshBySteelGrade(String steelGrade,Long yildStren,Long thick);

    /**
     * 查询光整机插入量列表
     * 
     * @param setupTmMesh 光整机插入量
     * @return 光整机插入量集合
     */
    public List<SetupTmMesh> selectSetupTmMeshList(SetupTmMesh setupTmMesh);

    /**
     * 新增光整机插入量
     * 
     * @param setupTmMesh 光整机插入量
     * @return 结果
     */
    public int insertSetupTmMesh(SetupTmMesh setupTmMesh);

    /**
     * 修改光整机插入量
     * 
     * @param setupTmMesh 光整机插入量
     * @return 结果
     */
    public int updateSetupTmMesh(SetupTmMesh setupTmMesh);

    /**
     * 批量删除光整机插入量
     * 
     * @param steelGrades 需要删除的光整机插入量主键集合
     * @return 结果
     */
    public int deleteSetupTmMeshBySteelGrades(String[] steelGrades,Long[] yildStrens,Long[] thicks);

    /**
     * 删除光整机插入量信息
     * 
     * @param steelGrade 光整机插入量主键
     * @return 结果
     */
    public int deleteSetupTmMeshBySteelGrade(String steelGrade);
}
